@@ -2,8 +2,14 @@ import re
 import logging
 import warnings
 
+import django
+from django.db import IntegrityError, transaction
 from django.utils import timezone
 from django.utils.encoding import smart_text
+try:
+    from django.utils.deprecation import MiddlewareMixin
+except ImportError:
+    MiddlewareMixin = object
 
 from tracking.models import Visitor, Pageview
 from tracking.utils import get_ip_address, total_seconds
@@ -12,17 +18,28 @@ from tracking.settings import (
     TRACK_ANONYMOUS_USERS,
     TRACK_IGNORE_STATUS_CODES,
     TRACK_IGNORE_URLS,
+    TRACK_IGNORE_USER_AGENTS,
     TRACK_PAGEVIEWS,
     TRACK_QUERY_STRING,
     TRACK_REFERER,
 )
 
 track_ignore_urls = [re.compile(x) for x in TRACK_IGNORE_URLS]
+track_ignore_user_agents = [
+    re.compile(x, re.IGNORECASE) for x in TRACK_IGNORE_USER_AGENTS
+]
 
 log = logging.getLogger(__file__)
 
+if django.VERSION < (1, 10):
+    def is_anonymous(user):
+        return user.is_anonymous()
+else:
+    def is_anonymous(user):
+        return user.is_anonymous
 
-class VisitorTrackingMiddleware(object):
+
+class VisitorTrackingMiddleware(MiddlewareMixin):
     def _should_track(self, user, request, response):
         # Session framework not installed, nothing to see here..
         if not hasattr(request, 'session'):
@@ -49,6 +66,12 @@ class VisitorTrackingMiddleware(object):
             if url.match(path):
                 return False
 
+        # Do not track ignored user agents
+        user_agent = request.META.get('HTTP_USER_AGENT', '')
+        for user_agent_pattern in track_ignore_user_agents:
+            if user_agent_pattern.match(user_agent):
+                return False
+
         # everything says we should track this hit
         return True
 
@@ -69,7 +92,7 @@ class VisitorTrackingMiddleware(object):
         # the user is object exists. Check using `user_id` to prevent
         # a database hit.
         if user and not visitor.user_id:
-            visitor.user = user
+            visitor.user_id = user.id
 
         # update some session expiration details
         visitor.expiry_age = request.session.get_expiry_age()
@@ -86,7 +109,17 @@ class VisitorTrackingMiddleware(object):
             time_on_site = total_seconds(visit_time - visitor.start_time)
         visitor.time_on_site = int(time_on_site)
 
-        visitor.save()
+        try:
+            with transaction.atomic():
+                visitor.save()
+        except IntegrityError:
+            # there is a small chance a second response has saved this
+            # Visitor already and a second save() at the same time (having
+            # failed to UPDATE anything) will attempt to INSERT the same
+            # session key (pk) again causing an IntegrityError
+            # If this happens we'll just grab the "winner" and use that!
+            visitor = Visitor.objects.get(pk=session_key)
+
         return visitor
 
     def _add_pageview(self, visitor, request, view_time):
@@ -110,7 +143,7 @@ class VisitorTrackingMiddleware(object):
         # session since if authentication happens, the `session_key` carries
         # over, thus having a more accurate start time of session
         user = getattr(request, 'user', None)
-        if user and user.is_anonymous():
+        if user and is_anonymous(user):
             # set AnonymousUsers to None for simplicity
             user = None
 
