@@ -1,16 +1,15 @@
 import logging
 
+from django.conf import settings
+from django.db import models
 from django.utils import timezone
+
+from tracking.managers import VisitorManager, PageviewManager
+from tracking.settings import TRACK_USING_GEOIP
+
 from django.contrib.gis.geoip import HAS_GEOIP
 if HAS_GEOIP:
     from django.contrib.gis.geoip import GeoIP, GeoIPException
-from django.db import models
-from django.conf import settings
-from django.contrib.auth.signals import user_logged_out
-from django.db.models.signals import post_save
-from tracking.managers import VisitorManager, PageviewManager
-from tracking.settings import TRACK_USING_GEOIP
-from .compat import User
 
 GEOIP_CACHE_TYPE = getattr(settings, 'GEOIP_CACHE_TYPE', 4)
 
@@ -19,8 +18,13 @@ log = logging.getLogger(__file__)
 
 class Visitor(models.Model):
     session_key = models.CharField(max_length=40, primary_key=True)
-    user = models.ForeignKey(User, related_name='visit_history',
-                             null=True, editable=False)
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL,
+        related_name='visit_history',
+        null=True,
+        editable=False,
+        on_delete=models.CASCADE,
+    )
     # Update to GenericIPAddress in Django 1.4
     ip_address = models.CharField(max_length=39, editable=False)
     user_agent = models.TextField(null=True, editable=False)
@@ -33,20 +37,20 @@ class Visitor(models.Model):
     objects = VisitorManager()
 
     def session_expired(self):
-        "The session has ended due to session expiration"
+        """The session has ended due to session expiration."""
         if self.expiry_time:
             return self.expiry_time <= timezone.now()
         return False
     session_expired.boolean = True
 
     def session_ended(self):
-        "The session has ended due to an explicit logout"
+        """The session has ended due to an explicit logout."""
         return bool(self.end_time)
     session_ended.boolean = True
 
     @property
     def geoip_data(self):
-        "Attempts to retrieve MaxMind GeoIP data based upon the visitor's IP"
+        """Attempt to retrieve MaxMind GeoIP data based on visitor's IP."""
         if not HAS_GEOIP or not TRACK_USING_GEOIP:
             return
 
@@ -70,7 +74,11 @@ class Visitor(models.Model):
 
 
 class Pageview(models.Model):
-    visitor = models.ForeignKey(Visitor, related_name='pageviews')
+    visitor = models.ForeignKey(
+        Visitor,
+        related_name='pageviews',
+        on_delete=models.CASCADE,
+    )
     url = models.TextField(null=False, editable=False)
     referer = models.TextField(null=True, editable=False)
     query_string = models.TextField(null=True, editable=False)
@@ -81,8 +89,3 @@ class Pageview(models.Model):
 
     class Meta(object):
         ordering = ('-view_time',)
-
-
-from tracking import handlers
-user_logged_out.connect(handlers.track_ended_session)
-post_save.connect(handlers.post_save_cache, sender=Visitor)
