@@ -1,6 +1,7 @@
 from __future__ import division
 
-import socket
+from django.core.exceptions import ValidationError
+from django.core.validators import validate_ipv46_address
 
 headers = (
     'HTTP_CLIENT_IP', 'HTTP_X_FORWARDED_FOR', 'HTTP_X_FORWARDED',
@@ -9,31 +10,16 @@ headers = (
 )
 
 
-def is_valid_ip_address(address_family, ip_str):
-    try:
-        socket.inet_pton(address_family, ip_str)
-    except socket.error:
-        return False
-    else:
-        return True
-
-
-def _is_valid_ipv4_address(ip_str):
-    return is_valid_ip_address(socket.AF_INET, ip_str)
-
-
-def _is_valid_ipv6_address(ip_str):
-    if ':' not in ip_str:
-        return False
-    return is_valid_ip_address(socket.AF_INET6, ip_str)
-
-
 def get_ip_address(request):
     for header in headers:
         if request.META.get(header, None):
             ip = request.META[header].split(',')[0]
-            if _is_valid_ipv6_address(ip) or _is_valid_ipv4_address(ip):
+
+            try:
+                validate_ipv46_address(ip)
                 return ip
+            except ValidationError:
+                pass
 
 
 def total_seconds(delta):
